@@ -20,8 +20,6 @@
 
 #include "renderjob.h"
 
-#include <stdlib.h> // for getenv, posix portable to Windows: http://msdn.microsoft.com/en-us/library/tehxacec(VS.80).aspx
-
 #include <QtDBus>
 #include <QFile>
 #include <QThread>
@@ -84,7 +82,7 @@ RenderJob::RenderJob(bool erase, bool usekuiserver, int pid, const QString& rend
     connect(m_renderProcess, SIGNAL(stateChanged(QProcess::ProcessState)), this, SLOT(slotCheckProcess(QProcess::ProcessState)));
     m_renderProcess->setReadChannel(QProcess::StandardError);
 
-    m_enablelog = (getenv("KDENLIVE_RENDER_LOG") != NULL);
+    m_enablelog = (!qgetenv("KDENLIVE_RENDER_LOG").isEmpty());
     if (m_enablelog) {
         // Create a log of every render process.
         m_logfile.setAutoRemove(false);
@@ -267,8 +265,8 @@ void RenderJob::start()
     // Because of the logging, we connect to stderr in all cases.
     connect(m_renderProcess, SIGNAL(readyReadStandardError()), this, SLOT(receivedStderr()));
     m_renderProcess->start(m_prog, m_args);
-    if (m_enablelog) m_logstream << "Started render process: " << m_prog << " " << m_args.join(QLatin1String(" ")) << endl;
-    qDebug() << "Started render process: " << m_prog << " " << m_args.join(QLatin1String(" "));
+    if (m_enablelog) m_logstream << "Started render process: " << m_prog << ' ' << m_args.join(QLatin1String(" ")) << endl;
+    qDebug() << "Started render process: " << m_prog << ' ' << m_args.join(QLatin1String(" "));
 }
 
 
@@ -356,27 +354,6 @@ void RenderJob::slotIsOver(QProcess::ExitStatus status, bool isWritable)
             m_dbusargs.append(QString());
             m_kdenliveinterface->callWithArgumentList(QDBus::NoBlock, QLatin1String("setRenderingFinished"), m_dbusargs);
         }
-        QDBusConnectionInterface* interface = QDBusConnection::sessionBus().interface();
-        if (!m_dualpass && interface && interface->isServiceRegistered(QLatin1String("org.kde.knotify"))) {
-            QDBusMessage m = QDBusMessage::createMethodCall(QLatin1String("org.kde.knotify"),
-                             QLatin1String("/Notify"),
-                             QLatin1String("org.kde.KNotify"),
-                             QLatin1String("event"));
-            int seconds = m_startTime.secsTo(QTime::currentTime());
-            QList<QVariant> args;
-            args.append(QLatin1String("RenderFinished"));   // action name
-            args.append(QLatin1String("kdenlive"));   // app name
-            args.append(QVariantList());   // contexts
-            args.append(tr("Rendering of %1 finished in %2").arg(m_dest, QTime(0, 0, seconds).toString(QLatin1String("hh:mm:ss"))));   // body
-            args.append(QByteArray());   // app icon
-            QStringList actionList;
-            args.append(actionList);   // actions
-            qlonglong wid = 0;
-            args.append(wid);   // win id
-
-            m.setArguments(args);
-            QDBusMessage replyMsg = QDBusConnection::sessionBus().call(m);
-        }
         if (m_enablelog) m_logstream << "Rendering of " << m_dest << " finished" << endl;
         qDebug() << "Rendering of " << m_dest << " finished";
         if (!m_dualpass && m_player != QLatin1String("-")) {
