@@ -22,13 +22,13 @@
 #define DEFINITIONS_H
 
 #include "gentime.h"
-#include "effectslist.h"
+#include "effectslist/effectslist.h"
 
 #include <KLocalizedString>
 #include <QDebug>
 
 #include <QTreeWidgetItem>
-#include <QtCore/QString>
+#include <QString>
 
 const int MAXCLIPDURATION = 15000;
 
@@ -245,7 +245,6 @@ class EffectsParameterList: public QList < EffectParameter >
 public:
     EffectsParameterList();
     bool hasParam(const QString &name) const;
-    void setParamValue(const QString &name, const QString &value);
 
     QString paramValue(const QString &name, const QString &defaultValue = QString()) const;
     void addParam(const QString &name, const QString &value);
