@@ -38,7 +38,7 @@
 #include <KColorScheme>
 
 MyEditableLabel::MyEditableLabel(QWidget * parent):
-    QLineEdit(parent)
+    KLineEdit(parent)
 {
     setFrame(false);
     setReadOnly(true);
@@ -86,7 +86,7 @@ CollapsibleGroup::CollapsibleGroup(int ix, bool firstGroup, bool lastGroup, cons
     menuButton->setMenu(m_menu);
     
     enabledButton->setChecked(false);
-    enabledButton->setIcon(KIcon("visible"));
+    enabledButton->setIcon(KIcon("layer-visible-on"));
     
     if (info.groupIsCollapsed) {
 	slotShow(false);
@@ -133,7 +133,7 @@ void CollapsibleGroup::slotEnable(bool disable, bool emitInfo)
     m_title->setEnabled(!disable);
     enabledButton->blockSignals(true);
     enabledButton->setChecked(disable);
-    enabledButton->setIcon(disable ? KIcon("novisible") : KIcon("visible"));
+    enabledButton->setIcon(disable ? KIcon("layer-visible-off") : KIcon("layer-visible-on"));
     enabledButton->blockSignals(false);
     for (int i = 0; i < m_subWidgets.count(); ++i)
 	m_subWidgets.at(i)->slotDisable(disable, emitInfo);
@@ -167,7 +167,7 @@ void CollapsibleGroup::slotEffectDown()
 
 void CollapsibleGroup::slotSaveGroup()
 {
-    QString name = QInputDialog::getText(this, i18n("Save Group"), i18n("Name for saved group: "), QLineEdit::Normal, m_title->text());
+    QString name = QInputDialog::getText(this, i18n("Save Group"), i18n("Name for saved group: "), KLineEdit::Normal, m_title->text());
     if (name.isEmpty()) return;
     QString path = KStandardDirs::locateLocal("appdata", "effects/", true);
     path = path + name + ".xml";
@@ -284,7 +284,7 @@ void CollapsibleGroup::updateTimecodeFormat()
 {
     QVBoxLayout *vbox = static_cast<QVBoxLayout *>(widgetFrame->layout());
     if (vbox == NULL) return;
-    for (int j = vbox->count() - 1; j >= 0; j--) {
+    for (int j = vbox->count() - 1; j >= 0; --j) {
 	CollapsibleEffect *e = static_cast<CollapsibleEffect *>(vbox->itemAt(j)->widget());
 	if (e) e->updateTimecodeFormat();
     }
@@ -377,7 +377,7 @@ void CollapsibleGroup::slotRenameGroup()
 {
     m_title->setReadOnly(true);
     if (m_title->text().isEmpty()) m_title->setText(i18n("Effect Group"));
-    for (int j = 0; j < m_subWidgets.count(); j++) {
+    for (int j = 0; j < m_subWidgets.count(); ++j) {
 	m_subWidgets.at(j)->setGroupName(m_title->text());
     }
     m_info.groupName = m_title->text();
@@ -397,7 +397,7 @@ QDomDocument CollapsibleGroup::effectsData()
     QDomElement list = doc.createElement("effectgroup");
     list.setAttribute("name", m_title->text());
     doc.appendChild(list);
-    for (int j = 0; j < m_subWidgets.count(); j++) {
+    for (int j = 0; j < m_subWidgets.count(); ++j) {
 	list.appendChild(doc.importNode(m_subWidgets.at(j)->effect(), true));
     }
     return doc;
