@@ -25,15 +25,15 @@
 #include "abstractcollapsiblewidget.h"
 #include "collapsibleeffect.h"
 #include "timecode.h"
-#include "keyframeedit.h"
+#include "effectstack/keyframeedit.h"
 
 #include <QDomElement>
 #include <QToolButton>
-#include <QLineEdit>
+#include <KLineEdit>
 #include <QMutex>
 
 
-class MyEditableLabel : public QLineEdit
+class MyEditableLabel : public KLineEdit
 {
     Q_OBJECT
 public:
