@@ -15,19 +15,19 @@
  *                                                                         *
  ***************************************************************************/
 
-
-#include "effectstackview2.h"
-#include "effectslist.h"
-#include "clipitem.h"
-#include "mainwindow.h"
-#include "docclipbase.h"
-#include "projectlist.h"
-#include "kthumb.h"
-#include "widgets/monitoreditwidget.h"
-#include "monitor/monitorscene.h"
-#include "kdenlivesettings.h"
 #include "collapsibleeffect.h"
 #include "collapsiblegroup.h"
+#include "effectstackview2.h"
+
+#include "kdenlivesettings.h"
+#include "mainwindow.h"
+#include "doc/kthumb.h"
+#include "doc/docclipbase.h"
+#include "project/projectlist.h"
+#include "effectslist/effectslist.h"
+#include "timeline/clipitem.h"
+#include "monitor/monitoreditwidget.h"
+#include "monitor/monitorscene.h"
 
 #include <KDebug>
 #include <KLocalizedString>
@@ -199,7 +199,7 @@ void EffectStackView2::setupListView()
         effectInfo.fromString(d.attribute("kdenlive_info"));
         if (effectInfo.groupIndex >= 0) {
             // effect is in a group
-            for (int j = 0; j < vbox1->count(); j++) {
+            for (int j = 0; j < vbox1->count(); ++j) {
                 CollapsibleGroup *eff = static_cast<CollapsibleGroup *>(vbox1->itemAt(j)->widget());
                 if (eff->isGroup() &&  eff->groupIndex() == effectInfo.groupIndex) {
                     group = eff;
