@@ -17,33 +17,36 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
+#include "parametercontainer.h"
+
+#include "complexparameter.h"
+#include "geometryval.h"
+#include "positionedit.h"
+#include "dragvalue.h"
+#include "widgets/kis_curve_widget.h"
+#include "widgets/kis_cubic_curve.h"
+#include "widgets/choosecolorwidget.h"
+#include "widgets/geometrywidget.h"
+#include "widgets/doubleparameterwidget.h"
+#include "widgets/cornerswidget.h"
+#include "widgets/bezier/beziersplinewidget.h"
+
+#include "kdenlivesettings.h"
+#include "mainwindow.h"
+#include "colortools.h"
+#include "dialogs/profilesdialog.h"
+#include "project/projectlist.h"
+#include "timeline/customtrackview.h"
+#ifdef USE_QJSON
+#include "onmonitoritems/rotoscoping/rotowidget.h"
+#endif
+
 #include "ui_listval_ui.h"
 #include "ui_boolval_ui.h"
 #include "ui_wipeval_ui.h"
 #include "ui_urlval_ui.h"
 #include "ui_keywordval_ui.h"
 #include "ui_fontval_ui.h"
-#include "complexparameter.h"
-#include "geometryval.h"
-#include "positionedit.h"
-#include "widgets/kis_curve_widget.h"
-#include "kis_cubic_curve.h"
-#include "widgets/choosecolorwidget.h"
-#include "widgets/geometrywidget.h"
-#include "colortools.h"
-#include "widgets/doubleparameterwidget.h"
-#include "widgets/cornerswidget.h"
-#include "dragvalue.h"
-#include "beziercurve/beziersplinewidget.h"
-#ifdef USE_QJSON
-#include "rotoscoping/rotowidget.h"
-#endif
-#include "kdenlivesettings.h"
-#include "profilesdialog.h"
-#include "projectlist.h"
-#include "mainwindow.h"
-#include "parametercontainer.h"
-#include "../customtrackview.h"
 
 #include <KUrlRequester>
 #include <KFileDialog>
@@ -179,7 +182,7 @@ ParameterContainer::ParameterContainer(const QDomElement &effect, const ItemInfo
             for (int i = 0; i < listitems.count(); ++i) {
                 lsval->list->addItem(listitemsdisplay.at(i), listitems.at(i));
                 QString entry = listitems.at(i);
-                if (!entry.isEmpty() && (entry.endsWith(".png") || entry.endsWith(".pgm"))) {
+                if (!entry.isEmpty() && (entry.endsWith(QLatin1String(".png")) || entry.endsWith(QLatin1String(".pgm")))) {
                     if (!MainWindow::m_lumacache.contains(entry)) {
                         QImage pix(entry);
                         MainWindow::m_lumacache.insert(entry, pix.scaled(30, 30, Qt::KeepAspectRatio, Qt::SmoothTransformation));
@@ -314,7 +317,7 @@ ParameterContainer::ParameterContainer(const QDomElement &effect, const ItemInfo
             QString inName = pa.attribute("inpoints");
             QString outName = pa.attribute("outpoints");
             int start = pa.attribute("min").toInt();
-            for (int j = start; j <= number; j++) {
+            for (int j = start; j <= number; ++j) {
                 QString in = inName;
                 in.replace("%i", QString::number(j));
                 QString out = outName;
@@ -500,13 +503,13 @@ ParameterContainer::~ParameterContainer()
 void ParameterContainer::meetDependency(const QString& name, const QString &type, const QString &value)
 {
     if (type == "curve") {
-        KisCurveWidget *curve = (KisCurveWidget*)m_valueItems[name];
+        KisCurveWidget *curve = static_cast<KisCurveWidget*>(m_valueItems[name]);
         if (curve) {
             const int color = value.toInt();
             curve->setPixmap(QPixmap::fromImage(ColorTools::rgbCurvePlane(curve->size(), (ColorTools::ColorsRGB)(color == 3 ? 4 : color), 0.8)));
         }
     } else if (type == "bezier_spline") {
-        BezierSplineWidget *widget = (BezierSplineWidget*)m_valueItems[name];
+        BezierSplineWidget *widget = static_cast<BezierSplineWidget*>(m_valueItems[name]);
         if (widget) {
             widget->setMode((BezierSplineWidget::CurveModes)((int)(value.toDouble() * 10 + 0.5)));
         }
@@ -520,13 +523,13 @@ wipeInfo ParameterContainer::getWipeInfo(QString value)
     if (value.contains(',')) value.replace(',','/');
     QString start = value.section(';', 0, 0);
     QString end = value.section(';', 1, 1).section('=', 1, 1);
-    if (start.startsWith("-100%/0"))
+    if (start.startsWith(QLatin1String("-100%/0")))
         info.start = LEFT;
-    else if (start.startsWith("100%/0"))
+    else if (start.startsWith(QLatin1String("100%/0")))
         info.start = RIGHT;
-    else if (start.startsWith("0%/100%"))
+    else if (start.startsWith(QLatin1String("0%/100%")))
         info.start = DOWN;
-    else if (start.startsWith("0%/-100%"))
+    else if (start.startsWith(QLatin1String("0%/-100%")))
         info.start = UP;
     else
         info.start = CENTER;
@@ -536,13 +539,13 @@ wipeInfo ParameterContainer::getWipeInfo(QString value)
     else
         info.startTransparency = 100;
 
-    if (end.startsWith("-100%/0"))
+    if (end.startsWith(QLatin1String("-100%/0")))
         info.end = LEFT;
-    else if (end.startsWith("100%/0"))
+    else if (end.startsWith(QLatin1String("100%/0")))
         info.end = RIGHT;
-    else if (end.startsWith("0%/100%"))
+    else if (end.startsWith(QLatin1String("0%/100%")))
         info.end = DOWN;
-    else if (end.startsWith("0%/-100%"))
+    else if (end.startsWith(QLatin1String("0%/-100%")))
         info.end = UP;
     else
         info.end = CENTER;
@@ -571,12 +574,12 @@ void ParameterContainer::updateTimecodeFormat()
             if (KdenliveSettings::on_monitor_effects()) {
                 if (m_geometryWidget) m_geometryWidget->updateTimecodeFormat();
             } else {
-                Geometryval *geom = ((Geometryval*)m_valueItems[paramName+"geometry"]);
+                Geometryval *geom = static_cast<Geometryval*>(m_valueItems[paramName+"geometry"]);
                 geom->updateTimecodeFormat();
             }
             break;
         } else if (type == "position") {
-            PositionEdit *posi = ((PositionEdit*)m_valueItems[paramName+"position"]);
+            PositionEdit *posi = static_cast<PositionEdit*>(m_valueItems[paramName+"position"]);
             posi->updateTimecodeFormat();
             break;
 #ifdef USE_QJSON
@@ -617,7 +620,7 @@ void ParameterContainer::slotCollectAllParameters()
 
         QString setValue;
         if (type == "double" || type == "constant") {
-            DoubleParameterWidget *doubleparam = (DoubleParameterWidget*)m_valueItems.value(paramName);
+            DoubleParameterWidget *doubleparam = static_cast<DoubleParameterWidget*>(m_valueItems.value(paramName));
             setValue = locale.toString(doubleparam->getValue());
         } else if (type == "list") {
             KComboBox *box = static_cast<Listval*>(m_valueItems.value(paramName))->list;
@@ -626,23 +629,23 @@ void ParameterContainer::slotCollectAllParameters()
             QCheckBox *box = static_cast<Boolval*>(m_valueItems.value(paramName))->checkBox;
             setValue = box->checkState() == Qt::Checked ? "1" : "0" ;
         } else if (type == "color") {
-            ChooseColorWidget *choosecolor = ((ChooseColorWidget*)m_valueItems.value(paramName));
+            ChooseColorWidget *choosecolor = static_cast<ChooseColorWidget*>(m_valueItems.value(paramName));
             setValue = choosecolor->getColor();
 	    if (pa.hasAttribute("paramprefix")) setValue.prepend(pa.attribute("paramprefix"));
         } else if (type == "complex") {
-            ComplexParameter *complex = ((ComplexParameter*)m_valueItems.value(paramName));
+            ComplexParameter *complex = static_cast<ComplexParameter*>(m_valueItems.value(paramName));
             namenode.item(i) = complex->getParamDesc();
         } else if (type == "geometry") {
             if (KdenliveSettings::on_monitor_effects()) {
                 if (m_geometryWidget) namenode.item(i).toElement().setAttribute("value", m_geometryWidget->getValue());
             } else {
-                Geometryval *geom = ((Geometryval*)m_valueItems.value(paramName));
+                Geometryval *geom = static_cast<Geometryval*>(m_valueItems.value(paramName));
                 namenode.item(i).toElement().setAttribute("value", geom->getValue());
             }
         } else if (type == "addedgeometry") {
             if (m_geometryWidget) namenode.item(i).toElement().setAttribute("value", m_geometryWidget->getExtraValue(namenode.item(i).toElement().attribute("name")));
         } else if (type == "position") {
-            PositionEdit *pedit = ((PositionEdit*)m_valueItems.value(paramName));
+            PositionEdit *pedit = static_cast<PositionEdit*>(m_valueItems.value(paramName));
             int pos = pedit->getPosition();
             setValue = QString::number(pos);
             if (m_effect.attribute("id") == "fadein" || m_effect.attribute("id") == "fade_from_black") {
@@ -665,7 +668,7 @@ void ParameterContainer::slotCollectAllParameters()
                 setValue.clear();
             }
         } else if (type == "curve") {
-            KisCurveWidget *curve = ((KisCurveWidget*)m_valueItems.value(paramName));
+            KisCurveWidget *curve = static_cast<KisCurveWidget*>(m_valueItems.value(paramName));
             QList<QPointF> points = curve->curve().points();
             QString number = pa.attribute("number");
             QString inName = pa.attribute("inpoints");
@@ -677,7 +680,7 @@ void ParameterContainer::slotCollectAllParameters()
             } else {
                 EffectsList::setParameter(m_effect, number, QString::number(points.count()));
             }
-            for (int j = 0; (j < points.count() && j + off <= end); j++) {
+            for (int j = 0; (j < points.count() && j + off <= end); ++j) {
                 QString in = inName;
                 in.replace("%i", QString::number(j + off));
                 QString out = outName;
@@ -689,7 +692,7 @@ void ParameterContainer::slotCollectAllParameters()
             if (!depends.isEmpty())
                 meetDependency(paramName, type, EffectsList::parameter(m_effect, depends));
         } else if (type == "bezier_spline") {
-            BezierSplineWidget *widget = (BezierSplineWidget*)m_valueItems.value(paramName);
+            BezierSplineWidget *widget = static_cast<BezierSplineWidget*>(m_valueItems.value(paramName));
             setValue = widget->spline();
             QString depends = pa.attribute("depends");
             if (!depends.isEmpty())
@@ -745,8 +748,8 @@ void ParameterContainer::slotCollectAllParameters()
             KUrlRequester *req = static_cast<Urlval*>(m_valueItems.value(paramName))->urlwidget;
             setValue = req->url().path();
 	} else if (type == "keywords"){
-            QLineEdit *line = static_cast<Keywordval*>(m_valueItems.value(paramName))->lineeditwidget;
-            QComboBox *combo = static_cast<Keywordval*>(m_valueItems.value(paramName))->comboboxwidget;
+            KLineEdit *line = static_cast<Keywordval*>(m_valueItems.value(paramName))->lineeditwidget;
+            KComboBox *combo = static_cast<Keywordval*>(m_valueItems.value(paramName))->comboboxwidget;
             if(combo->currentIndex())
             {
                 QString comboval = combo->itemData(combo->currentIndex()).toString();
@@ -832,13 +835,13 @@ void ParameterContainer::slotStartFilterJobAction()
 		QDomNodeList params = m_effect.elementsByTagName("parameter");
 		CustomTrackView::adjustEffectParameters(parameters, params, m_metaInfo->profile);
 		QString paramData;
-		for (int j = 0; j < parameters.count(); j++)
-		    paramData.append(parameters.at(j).name()+"="+parameters.at(j).value()+" ");
+		for (int j = 0; j < parameters.count(); ++j)
+		    paramData.append(parameters.at(j).name()+'='+parameters.at(j).value()+' ');
 		filterparams.replace("%params", paramData);
 	    }
 	    QMap <QString, QString> extraParams;
 	    QDomNodeList jobparams = pa.elementsByTagName("jobparam");
-	    for (int j = 0; j < jobparams.count(); j++) {
+	    for (int j = 0; j < jobparams.count(); ++j) {
                 QDomElement e = jobparams.item(j).toElement();
 		extraParams.insert(e.attribute("name"), e.text().toUtf8());
 	    }
