@@ -44,10 +44,10 @@ public:
       Correlates the two vectors envMain and envSub.
       \c correlation must be a pre-allocated vector of size sizeMain+sizeSub+1.
       */
-    static void correlate(const int64_t *envMain, int sizeMain,
-                          const int64_t *envSub, int sizeSub,
-                          int64_t *correlation,
-                          int64_t *out_max = NULL);
+    static void correlate(const qint64 *envMain, int sizeMain,
+                          const qint64 *envSub, int sizeSub,
+                          qint64 *correlation,
+                          qint64 *out_max = NULL);
 private:
     AudioEnvelope *m_mainTrackEnvelope;
 
