@@ -8,13 +8,13 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#include "fftTools.h"
+
 #include <math.h>
 #include <iostream>
 
 #include <QString>
 
-#include "fftTools.h"
-
 // Uncomment for debugging, like writing a GNU Octave .m file to /tmp
 //#define DEBUG_FFTTOOLS
 
@@ -64,10 +64,10 @@ const QVector<float> FFTTools::window(const WindowType windowType, const int siz
     case Window_Triangle:
         window = QVector<float>(size+1);
 
-        for (int x = 0; x < mid; x++) {
+        for (int x = 0; x < mid; ++x) {
             window[x] = x/mid + (mid-x)/mid*param;
         }
-        for (int x = mid; x < size; x++) {
+        for (int x = mid; x < size; ++x) {
             window[x] = (x-mid)/(max-mid) * param + (max-x)/(max-mid);
         }
         window[size] = .5 + param/2;
@@ -88,7 +88,7 @@ const QVector<float> FFTTools::window(const WindowType windowType, const int siz
         // we use integer values instead, ranging from -mid to (max-mid).
         window = QVector<float>(size+1);
 
-        for (int x = 0; x < size; x++) {
+        for (int x = 0; x < size; ++x) {
             window[x] = .54 + .46 * cos( 2*M_PI*(x-mid) / size );
         }
 
@@ -111,7 +111,7 @@ const QVector<float> FFTTools::window(const WindowType windowType, const int siz
     return QVector<float>();
 }
 
-void FFTTools::fftNormalized(const QVector<int16_t> audioFrame, const uint channel, const uint numChannels, float *freqSpectrum,
+void FFTTools::fftNormalized(const QVector<qint16> audioFrame, const uint channel, const uint numChannels, float *freqSpectrum,
                              const WindowType windowType, const uint windowSize, const float param)
 {
 #ifdef DEBUG_FFTTOOLS
@@ -207,14 +207,14 @@ void FFTTools::fftNormalized(const QVector<int16_t> audioFrame, const uint chann
     } else {
         mFile << "val = [ ";
 
-        for (int sample = 0; sample < 256; sample++) {
-            mFile << data[sample] << " ";
+        for (int sample = 0; sample < 256; ++sample) {
+            mFile << data[sample] << ' ';
         }
         mFile << " ];\n";
 
         mFile << "freq = [ ";
-        for (int sample = 0; sample < 256; sample++) {
-            mFile << freqData[sample].r << "+" << freqData[sample].i << "*i ";
+        for (int sample = 0; sample < 256; ++sample) {
+            mFile << freqData[sample].r << '+' << freqData[sample].i << "*i ";
         }
         mFile << " ];\n";
 
@@ -244,10 +244,10 @@ const QVector<float> FFTTools::interpolatePeakPreserving(const QVector<float> in
 
 
     float x;
-    float x_prev = 0;
     uint xi;
     uint i;
     if (((float) (right-left))/targetSize < 2) {
+        float x_prev = 0;
         for (i = 0; i < targetSize; ++i) {
 
             // i:  Target index
@@ -292,24 +292,17 @@ const QVector<float> FFTTools::interpolatePeakPreserving(const QVector<float> in
         // If there are more than 2 samples per pixel in average, then use the maximum of them
         // since by only looking at the left sample we might miss some maxima.
         uint src = left;
-//         int xi_prev = 0;
-        int points;
-
-#ifdef DEBUG_FFTTOOLS
-        qDebug() << "Interpolation: Ratio over 2; using maximum interpolation";
-#endif
-
         for (i = 0; i < targetSize; ++i) {
 
             // x:  right bound
             // xi: floor(x)
             x = ((float) (i+1)) / (targetSize-1) * (right-left) + left;
             xi = (int) floor(x);
-            points = 0;
+            int points = 0;
 
             out[i] = fill;
 
-            for (; src < xi && src < (uint) in.size(); src++) {
+            for (; src < xi && src < (uint) in.size(); ++src) {
                 if (out[i] < in[src]) {
                     out[i] = in[src];
                 }
