@@ -18,14 +18,15 @@
  ***************************************************************************/
 
 
-#include "monitor/monitor.h"
+#include "monitor.h"
+#include "monitorscene.h"
+#include "monitoreditwidget.h"
+#include "videosurface.h"
 #include "smallruler.h"
-#include "docclipbase.h"
-#include "abstractclipitem.h"
-#include "monitor/monitorscene.h"
-#include "widgets/monitoreditwidget.h"
-#include "widgets/videosurface.h"
+
 #include "kdenlivesettings.h"
+#include "doc/docclipbase.h"
+#include "timeline/abstractclipitem.h"
 
 #include <KDebug>
 #include <KLocalizedString>
@@ -97,7 +98,6 @@ Monitor::Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QString profil
     QToolButton *playButton = new QToolButton(m_toolbar);
     m_playMenu = new QMenu(i18n("Play..."), this);
     m_playAction = m_playMenu->addAction(m_playIcon, i18n("Play"));
-    //m_playAction->setCheckable(true);
     connect(m_playAction, SIGNAL(triggered()), this, SLOT(slotPlay()));
 
     playButton->setMenu(m_playMenu);
@@ -315,7 +315,7 @@ void Monitor::slotSetSizeOneToOne()
     const int maxHeight = r.height() - 20;
     int width = render->renderWidth();
     int height = render->renderHeight();
-    kDebug() << "// render info: " << width << "x" << height;
+    kDebug() << "// render info: " << width << 'x' << height;
     while (width >= maxWidth || height >= maxHeight) {
         width = width * 0.8;
         height = height * 0.8;
@@ -335,7 +335,7 @@ void Monitor::slotSetSizeOneToTwo()
     const int maxHeight = r.height() - 20;
     int width = render->renderWidth() / 2;
     int height = render->renderHeight() / 2;
-    kDebug() << "// render info: " << width << "x" << height;
+    kDebug() << "// render info: " << width << 'x' << height;
     while (width >= maxWidth || height >= maxHeight) {
         width = width * 0.8;
         height = height * 0.8;
@@ -711,8 +711,8 @@ void Monitor::slotRewind(double speed)
 		render->play(-8);
 	}
     } else render->play(speed);
-    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
+    m_playAction->setToolTip(i18n("Pause"));
 }
 
 void Monitor::slotForward(double speed)
@@ -735,8 +735,8 @@ void Monitor::slotForward(double speed)
 		render->play(8);
 	}
     } else render->play(speed);
-    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
+    m_playAction->setToolTip(i18n("Pause"));
 }
 
 void Monitor::slotRewindOneFrame(int diff)
@@ -770,6 +770,7 @@ void Monitor::rendererStopped(int pos)
 	checkOverlay();
     }
     m_playAction->setIcon(m_playIcon);
+    m_playAction->setToolTip(i18n("Play"));
 }
 
 void Monitor::adjustRulerSize(int length)
@@ -818,12 +819,8 @@ void Monitor::pause()
     if (render == NULL) return;
     slotActivateMonitor();
     render->pause();
-    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_playIcon);
-}
-
-void Monitor::unpause()
-{
+    m_playAction->setToolTip(i18n("Play"));
 }
 
 void Monitor::slotPlay()
@@ -831,11 +828,13 @@ void Monitor::slotPlay()
     if (render == NULL) return;
     slotActivateMonitor();
     if (render->isPlaying()) {
-	m_playAction->setIcon(m_playIcon);
+        m_playAction->setIcon(m_playIcon);
+        m_playAction->setToolTip(i18n("Play"));
         render->switchPlay(false);
     }
     else {
         m_playAction->setIcon(m_pauseIcon);
+        m_playAction->setToolTip(i18n("Pause"));
         render->switchPlay(true);
     }
     m_ruler->refreshRuler();
@@ -847,8 +846,8 @@ void Monitor::slotPlayZone()
     slotActivateMonitor();
     QPoint p = m_ruler->zone();
     render->playZone(GenTime(p.x(), m_monitorManager->timecode().fps()), GenTime(p.y(), m_monitorManager->timecode().fps()));
-    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
+    m_playAction->setToolTip(i18n("Pause"));
 }
 
 void Monitor::slotLoopZone()
@@ -857,8 +856,8 @@ void Monitor::slotLoopZone()
     slotActivateMonitor();
     QPoint p = m_ruler->zone();
     render->loopZone(GenTime(p.x(), m_monitorManager->timecode().fps()), GenTime(p.y(), m_monitorManager->timecode().fps()));
-    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
+    m_playAction->setToolTip(i18n("Pause"));
 }
 
 void Monitor::slotLoopClip()
@@ -867,8 +866,8 @@ void Monitor::slotLoopClip()
         return;
     slotActivateMonitor();
     render->loopZone(m_selectedClip->startPos(), m_selectedClip->endPos());
-    //m_playAction->setChecked(true);
     m_playAction->setIcon(m_pauseIcon);
+    m_playAction->setToolTip(i18n("Pause"));
 }
 
 void Monitor::updateClipProducer(Mlt::Producer *prod)
@@ -1051,7 +1050,7 @@ void Monitor::slotSetSelectedClip(ClipItem* item)
 {
     if (item || (!item && !m_loopClipTransition)) {
         m_loopClipTransition = false;
-        slotSetSelectedClip((AbstractClipItem*)item);
+        slotSetSelectedClip((AbstractClipItem*)item); //FIXME static_cast fails!
     }
 }
 
@@ -1059,7 +1058,7 @@ void Monitor::slotSetSelectedClip(Transition* item)
 {
     if (item || (!item && m_loopClipTransition)) {
         m_loopClipTransition = true;
-        slotSetSelectedClip((AbstractClipItem*)item);
+        slotSetSelectedClip((AbstractClipItem*)item); //FIXME static_cast fails!
     }
 }
 
@@ -1220,4 +1219,5 @@ void Overlay::setOverlayText(const QString &text, bool isZone)
 }
 
 
-#include "monitor/monitor.moc"
+#include "monitor.moc"
+
