@@ -17,16 +17,17 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
  ***************************************************************************/
 
-#include "monitor/recmonitor.h"
+#include "recmonitor.h"
+#include "monitor.h"
+#include "monitormanager.h"
+
 #include "gentime.h"
-#include "mltdevicecapture.h"
 #include "kdenlivesettings.h"
-#include "managecapturesdialog.h"
-#include "monitor/monitormanager.h"
-#include "monitor/monitor.h"
-#include "profilesdialog.h"
-#include "widgets/videosurface.h"
-#include "config-kdenlive.h"
+#include "capture/mltdevicecapture.h"
+#include "capture/managecapturesdialog.h"
+#include "dialogs/profilesdialog.h"
+#include "videosurface.h"
+#include <config-kdenlive.h>
 
 #include <KDebug>
 #include <KLocalizedString>
@@ -43,6 +44,7 @@
 #include <QToolButton>
 #include <QFile>
 #include <QDir>
+#include <QPainter>
 #include <QDesktopWidget>
 
 
@@ -120,7 +122,7 @@ RecMonitor::RecMonitor(Kdenlive::MonitorId name, MonitorManager *manager, QWidge
     m_logger.setMaxCount(10);
     m_logger.setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_logger.setFrame(false);
-    //m_logger.setInsertPolicy(QComboBox::InsertAtTop);
+    //m_logger.setInsertPolicy(KComboBox::InsertAtTop);
     
     m_freeSpace = new KCapacityBar(KCapacityBar::DrawTextInline, this);
     m_freeSpace->setMaximumWidth(150);
@@ -183,6 +185,9 @@ RecMonitor::~RecMonitor()
     delete m_captureProcess;
     delete m_displayProcess;
     delete m_captureDevice;
+#if KDE_IS_VERSION(4,7,0)
+    delete m_infoMessage;
+#endif
 }
 
 void RecMonitor::mouseDoubleClickEvent(QMouseEvent * event)
@@ -426,6 +431,7 @@ void RecMonitor::slotStopCapture()
     case Firewire:
         m_captureProcess->write("\e", 2);
         m_playAction->setIcon(m_playIcon);
+        m_playAction->setToolTip(i18n("Play"));
         m_isPlaying = false;
         break;
     case ScreenBag:
@@ -465,10 +471,12 @@ void RecMonitor::slotStartPreview(bool play)
                 m_captureProcess->write("k", 1);
                 //captureProcess->write("\e", 2);
                 m_playAction->setIcon(m_playIcon);
+                m_playAction->setToolTip(i18n("Play"));
                 m_isPlaying = false;
             } else {
                 m_captureProcess->write("p", 1);
                 m_playAction->setIcon(m_pauseIcon);
+                m_playAction->setToolTip(i18n("Pause"));
                 m_isPlaying = true;
             }
         }
@@ -624,7 +632,6 @@ void RecMonitor::slotRecord()
         QString args;
         QString playlist;
         QString v4lparameters;
-	QStringList grabParameters;
         MltVideoProfile profile;
         bool showPreview;
 	bool isXml;
@@ -727,18 +734,18 @@ void RecMonitor::slotRecord()
 	    captureSize = ":0.0";
             if (KdenliveSettings::grab_capture_type() == 0) {
                 // Full screen capture
-		m_captureArgs << "-s" << QString::number(screenSize.width()) + "x" + QString::number(screenSize.height());
+		m_captureArgs << "-s" << QString::number(screenSize.width()) + 'x' + QString::number(screenSize.height());
 	    } else {
                 // Region capture
-                m_captureArgs << "-s" << QString::number(KdenliveSettings::grab_width()) + "x" + QString::number(KdenliveSettings::grab_height());
-                captureSize.append("+" + QString::number(KdenliveSettings::grab_offsetx()) + "." + QString::number(KdenliveSettings::grab_offsetx()));
+                m_captureArgs << "-s" << QString::number(KdenliveSettings::grab_width()) + 'x' + QString::number(KdenliveSettings::grab_height());
+                captureSize.append("+" + QString::number(KdenliveSettings::grab_offsetx()) + '.' + QString::number(KdenliveSettings::grab_offsetx()));
             }
             // fps
             m_captureArgs << "-r" << QString::number(KdenliveSettings::grab_fps());
             if (KdenliveSettings::grab_hide_mouse()) captureSize.append("+nomouse");
 	    m_captureArgs << "-i" << captureSize;
-	    grabParameters = KdenliveSettings::grab_parameters().simplified().split(" ");
-	    m_captureArgs << grabParameters;
+        if (!KdenliveSettings::grab_parameters().simplified().isEmpty())
+            m_captureArgs << KdenliveSettings::grab_parameters().simplified().split(' ');
 	    m_captureArgs << path;
 	    
             m_isCapturing = true;
@@ -858,7 +865,7 @@ void RecMonitor::slotStartGrab(const QRect &rect) {
     int height = rect.height();
     if (width % 2 != 0) width--;
     if (height % 2 != 0) height--;
-    QString args = KdenliveSettings::screengrabcapture().replace("%size", QString::number(width) + "x" + QString::number(height)).replace("%offset", "+" + QString::number(rect.x()) + "," + QString::number(rect.y()));
+    QString args = KdenliveSettings::screengrabcapture().replace("%size", QString::number(width) + 'x' + QString::number(height)).replace("%offset", "+" + QString::number(rect.x()) + ',' + QString::number(rect.y()));
     if (KdenliveSettings::screengrabenableaudio()) {
         // also capture audio
         if (KdenliveSettings::useosscapture()) m_captureArgs << KdenliveSettings::screengrabosscapture().simplified().split(' ');
@@ -899,6 +906,7 @@ void RecMonitor::slotProcessStatus(QProcess::ProcessState status)
 	}
         m_isPlaying = false;
         m_playAction->setIcon(m_playIcon);
+        m_playAction->setToolTip(i18n("Play"));
         m_recAction->setChecked(false);
         m_stopAction->setEnabled(false);
         device_selector->setEnabled(true);
@@ -999,14 +1007,6 @@ void RecMonitor::slotUpdateFreeSpace()
     }
 }
 
-void RecMonitor::refreshRecMonitor(bool visible)
-{
-    if (visible) {
-        //if (!m_isActive) activateMonitor();
-
-    }
-}
-
 void RecMonitor::slotPlay()
 {
     /*if (m_isPlaying) slotStopCapture();
@@ -1017,7 +1017,7 @@ void RecMonitor::slotReadProcessInfo()
 {
     QString data = m_captureProcess->readAllStandardError().simplified();
     if (device_selector->currentIndex() == ScreenBag) {
-	m_error.append(data + "\n");
+	m_error.append(data + '\n');
     }
     else if (device_selector->currentIndex() == Firewire) {
 	data = data.section('"', 2, 2).simplified();
@@ -1070,5 +1070,5 @@ void RecMonitor::slotMouseSeek(int /*eventDelta*/, bool /*fast*/)
 }
 
 
-#include "monitor/recmonitor.moc"
+#include "recmonitor.moc"
 
