@@ -9,6 +9,7 @@
  ***************************************************************************/
 
 #include "abstractaudioscopewidget.h"
+
 #include "renderer.h"
 #include "monitor/monitor.h"
 
@@ -30,10 +31,10 @@ AbstractAudioScopeWidget::AbstractAudioScopeWidget(bool trackMouse, QWidget *par
 {
 }
 
-void AbstractAudioScopeWidget::slotReceiveAudio(const QVector<int16_t>& sampleData, int freq, int num_channels, int num_samples)
+void AbstractAudioScopeWidget::slotReceiveAudio(const QVector<qint16>& sampleData, int freq, int num_channels, int num_samples)
 {
 #ifdef DEBUG_AASW
-    qDebug() << "Received audio for " << widgetName() << ".";
+    qDebug() << "Received audio for " << widgetName() << '.';
 #endif
     m_audioFrame = sampleData;
     m_freq = freq;
