@@ -11,6 +11,7 @@
 
 
 #include "audiospectrum.h"
+
 #include "lib/audio/fftTools.h"
 #include "lib/external/kiss_fft/tools/kiss_fftr.h"
 
@@ -172,7 +173,7 @@ QImage AudioSpectrum::renderBackground(uint)
     return QImage();
 }
 
-QImage AudioSpectrum::renderAudioScope(uint, const QVector<int16_t> &audioFrame, const int freq, const int num_channels,
+QImage AudioSpectrum::renderAudioScope(uint, const QVector<qint16> &audioFrame, const int freq, const int num_channels,
                                        const int num_samples, const int)
 {
     if (
@@ -192,8 +193,8 @@ QImage AudioSpectrum::renderAudioScope(uint, const QVector<int16_t> &audioFrame,
 
         for (int i = 0; i < audioFrame.size(); ++i) {
             if (
-                    audioFrame[i] == std::numeric_limits<int16_t>::max()
-                    || audioFrame[i] == std::numeric_limits<int16_t>::min()) {
+                    audioFrame[i] == std::numeric_limits<qint16>::max()
+                    || audioFrame[i] == std::numeric_limits<qint16>::min()) {
                 overmodulateCount++;
                 if (overmodulateCount > 3) {
                     overmodulated = true;
@@ -296,7 +297,7 @@ QImage AudioSpectrum::renderAudioScope(uint, const QVector<int16_t> &audioFrame,
 #ifdef AUDIOSPEC_LINES
             davinci.drawLine(leftDist + i, topDist + h-1, leftDist + i, topDist + h-1 - yMax);
 #else
-            for (int y = 0; y < yMax && y < (int)h; y++) {
+            for (int y = 0; y < yMax && y < (int)h; ++y) {
                 spectrum.setPixel(leftDist + i, topDist + h-y-1, spectrumColor.rgba());
             }
 #endif
@@ -409,7 +410,7 @@ QImage AudioSpectrum::renderHUD(uint)
             if (hz > 0) {
                 // Draw finer lines between the main lines
                 davinci.setPen(AbstractScopeWidget::penLightDots);
-                for (uint dHz = 3; dHz > 0; dHz--) {
+                for (uint dHz = 3; dHz > 0; --dHz) {
                     x = leftDist + m_innerScopeRect.width() * ((float)hz - dHz * hzDiff/4.0f)/m_freqMax;
                     if (x > rightBorder) {
                         break;
@@ -489,7 +490,7 @@ QImage AudioSpectrum::renderHUD(uint)
     } else {
 #ifdef DEBUG_AUDIOSPEC
         qDebug() << "Widget is too small for painting inside. Size of inner scope rect is "
-                 << m_innerScopeRect.width() << "x" << m_innerScopeRect.height() <<".";
+                 << m_innerScopeRect.width() << 'x' << m_innerScopeRect.height() <<".";
 #endif
         emit signalHUDRenderingFinished(0, 1);
         return QImage();
