@@ -12,6 +12,11 @@
 #ifndef AUDIOSPECTRUM_H
 #define AUDIOSPECTRUM_H
 
+#include "abstractaudioscopewidget.h"
+#include "lib/external/kiss_fft/tools/kiss_fftr.h"
+#include "lib/audio/fftTools.h"
+#include "ui_audiospectrum_ui.h"
+
 // Enables debugging
 //#define DEBUG_AUDIOSPEC
 
@@ -21,11 +26,6 @@
 #include <QVector>
 #include <QHash>
 
-#include "abstractaudioscopewidget.h"
-#include "ui_audiospectrum_ui.h"
-#include "lib/external/kiss_fft/tools/kiss_fftr.h"
-#include "lib/audio/fftTools.h"
-
 class AudioSpectrum_UI;
 
 /**
@@ -50,7 +50,7 @@ protected:
     ///// Implemented methods /////
     QRect scopeRect();
     QImage renderHUD(uint accelerationFactor);
-    QImage renderAudioScope(uint accelerationFactor, const QVector<int16_t> &audioFrame, const int freq, const int num_channels, const int num_samples, const int newData);
+    QImage renderAudioScope(uint accelerationFactor, const QVector<qint16> &audioFrame, const int freq, const int num_channels, const int num_samples, const int newData);
     QImage renderBackground(uint accelerationFactor);
     bool isHUDDependingOnInput() const;
     bool isScopeDependingOnInput() const;
