@@ -81,6 +81,14 @@ Spectrogram::Spectrogram(QWidget *parent) :
     connect(this, SIGNAL(signalMousePositionChanged()), this, SLOT(forceUpdateHUD()));
 
     AbstractScopeWidget::init();
+
+    for (int i = 0; i <= 255/5; ++i) {
+        m_colorMap[i + 0*255/5] = qRgb(  0,   0, i*5); // black to blue
+        m_colorMap[i + 1*255/5] = qRgb(  0, i*5, 255); // blue to cyan
+        m_colorMap[i + 2*255/5] = qRgb(  0, 255, 255-i*5); // cyan to green
+        m_colorMap[i + 3*255/5] = qRgb(i*5, 255, 0); // green to yellow
+        m_colorMap[i + 4*255/5] = qRgb(255, 255-i*5, 0); // yellow to red
+    }
 }
 
 Spectrogram::~Spectrogram()
@@ -250,7 +258,7 @@ QImage Spectrogram::renderHUD(uint)
                 if (hz > 0) {
                     // Draw finer lines between the main lines
                     davinci.setPen(AbstractScopeWidget::penLightDots);
-                    for (uint dHz = 3; dHz > 0; dHz--) {
+                    for (uint dHz = 3; dHz > 0; --dHz) {
                         x = leftDist + m_innerScopeRect.width() * ((float)hz - dHz * hzDiff/4.0f)/m_freqMax;
                         if (x > rightBorder) {
                             break;
@@ -279,12 +287,11 @@ QImage Spectrogram::renderHUD(uint)
         }
 
         // Draw the dB brightness scale
-        float val;
         davinci.setPen(AbstractScopeWidget::penLighter);
-        for (y = topDist; y < (int)topDist + m_innerScopeRect.height(); y++) {
-            val = 1-((float)y-topDist)/(m_innerScopeRect.height()-1);
-            int col = qRgba(255, 255, 255, 255.0 * val);
-            for (x = leftDist-6; x >= (int)leftDist-13; x--) {
+        for (y = topDist; y < (int)topDist + m_innerScopeRect.height(); ++y) {
+            float val = 1-((float)y-topDist)/(m_innerScopeRect.height()-1);
+            int col = m_colorMap[(int)(val * 255)];
+            for (x = leftDist-6; x >= (int)leftDist-13; --x) {
                 hud.setPixel(x, y, col);
             }
         }
@@ -302,7 +309,7 @@ QImage Spectrogram::renderHUD(uint)
         return QImage();
     }
 }
-QImage Spectrogram::renderAudioScope(uint, const QVector<int16_t> &audioFrame, const int freq,
+QImage Spectrogram::renderAudioScope(uint, const QVector<qint16> &audioFrame, const int freq,
                                      const int num_channels, const int num_samples, const int newData) {
     if (
             audioFrame.size() > 63
@@ -408,7 +415,7 @@ QImage Spectrogram::renderAudioScope(uint, const QVector<int16_t> &audioFrame, c
                         val = 1;
                     }
                     if (!peak || !m_aHighlightPeaks->isChecked()) {
-                        spectrum.setPixel(leftDist + i, topDist + h-1 - y, qRgba(255, 255, 255, val * 255));
+                        spectrum.setPixel(leftDist + i, topDist + h-1 - y, m_colorMap[(int)(val * 255)]);
                     } else {
                         spectrum.setPixel(leftDist + i, topDist + h-1 - y, AbstractScopeWidget::colHighlightDark.rgba());
                     }
