@@ -44,7 +44,7 @@ protected:
     ///// Implemented methods /////
     QRect scopeRect();
     QImage renderHUD(uint accelerationFactor);
-    QImage renderAudioScope(uint accelerationFactor, const QVector<int16_t> &audioFrame, const int freq, const int num_channels, const int num_samples, const int newData);
+    QImage renderAudioScope(uint accelerationFactor, const QVector<qint16> &audioFrame, const int freq, const int num_channels, const int num_samples, const int newData);
     QImage renderBackground(uint accelerationFactor);
     bool isHUDDependingOnInput() const;
     bool isScopeDependingOnInput() const;
@@ -74,6 +74,7 @@ private:
     bool m_parameterChanged;
 
     QRect m_innerScopeRect;
+    QRgb m_colorMap[256];
 
 private slots:
     void slotResetMaxFreq();
