@@ -8,6 +8,11 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#include "vectorscope.h"
+#include "colorplaneexport.h"
+#include "vectorscopegenerator.h"
+
+#include "colortools.h"
 
 #include <QAction>
 #include <QDebug>
@@ -16,11 +21,6 @@
 #include <QTime>
 #include <QMenu>
 
-#include "colorplaneexport.h"
-#include "colortools.h"
-#include "vectorscope.h"
-#include "colorcorrection/vectorscopegenerator.h"
-
 const float P75 = .75;
 
 const QPointF YUV_R(-.147,  .615);
