@@ -8,17 +8,16 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#include "waveform.h"
+#include "waveformgenerator.h"
+// For reading out the project resolution
+#include "kdenlivesettings.h"
+#include "dialogs/profilesdialog.h"
+
 #include <QPainter>
 #include <QPoint>
 #include <QMenu>
 
-// For reading out the project resolution
-#include "kdenlivesettings.h"
-#include "profilesdialog.h"
-
-#include "waveform.h"
-#include "colorcorrection/waveformgenerator.h"
-
 
 const QSize Waveform::m_textWidth(35,0);
 const int Waveform::m_paddingBottom(20);
@@ -121,8 +120,6 @@ QImage Waveform::renderHUD(uint)
     const int y = m_mousePos.y() - scopeRect().y();
 
     if (scopeRect().height() > 0 && m_mouseWithinWidget) {
-        const int top = 30;
-        const int bottom = 20;
         int val = 255*(1-(float)y/scopeRect().height());
 
         if (val >= 0 && val <= 255) {
@@ -132,6 +129,8 @@ QImage Waveform::renderHUD(uint)
 
             // Make the value stick to the line unless it is at the top/bottom of the scope
             int valY = y+5;
+            const int top = 30;
+            const int bottom = 20;
             if (valY < top) {
                 valY = top;
             } else if (valY > scopeRect().height()-bottom) {
