@@ -17,11 +17,11 @@
 
 #include "stopmotion.h"
 #ifdef USE_V4L
-#include "v4l/v4lcapture.h"
+#include "capture/v4lcapture.h"
 #endif
-#include "slideshowclip.h"
-#include "profilesdialog.h"
-#include "mltdevicecapture.h"
+#include "project/dialogs/slideshowclip.h"
+#include "dialogs/profilesdialog.h"
+#include "capture/mltdevicecapture.h"
 #include "monitor/recmonitor.h"
 #include "monitor/monitormanager.h"
 #include "ui_smconfig_ui.h"
@@ -37,7 +37,7 @@
 
 #include <QtConcurrentRun>
 #include <QInputDialog>
-#include <QComboBox>
+#include <KComboBox>
 #include <QVBoxLayout>
 #include <QTimer>
 #include <QPainter>
@@ -838,17 +838,6 @@ QListWidgetItem* StopmotionWidget::getFrameFromIndex(int ix)
     return NULL;
 }
 
-
-void StopmotionWidget::selectFrame(int ix)
-{
-    frame_list->blockSignals(true);
-    QListWidgetItem* item = getFrameFromIndex(ix);
-    if (!item)
-        return;
-    frame_list->setCurrentItem(item);
-    frame_list->blockSignals(false);
-}
-
 void StopmotionWidget::slotSeekFrame(bool forward)
 {
     int ix = frame_list->currentRow();
