@@ -81,11 +81,11 @@ return frameNumber;
 
 
 
+#include "timecode.h"
+
 #include <KDebug>
 #include <KLocalizedString>
 
-#include "timecode.h"
-
 Timecode::Timecode(Formats format, double framesPerSecond)
 {
     setFormat(framesPerSecond, format);
@@ -112,11 +112,6 @@ double Timecode::fps() const
     return m_realFps;
 }
 
-bool Timecode::df() const
-{
-    return m_dropFrameTimecode;
-}
-
 const QString Timecode::mask(const GenTime& t) const
 {
     if (t < GenTime()) {
@@ -134,12 +129,6 @@ QString Timecode::reformatSeparators(QString duration) const
     return duration.replace(8, 1, ':');
 }
 
-int Timecode::getDisplayFrameCount(const QString &duration, bool frameDisplay) const
-{
-    if (frameDisplay) return duration.toInt();
-    return getFrameCount(duration);
-}
-
 int Timecode::getFrameCount(const QString &duration) const
 {
     if (duration.isEmpty()) {
