@@ -74,7 +74,7 @@ public:
     SERVICETYPE serviceType;
 
 public slots:
-    virtual void slotStartSearch(const QString searchText, int page = 0);
+    virtual void slotStartSearch(const QString &searchText, int page = 0);
     virtual OnlineItemInfo displayItemDetails(QListWidgetItem *item);
     virtual bool startItemPreview(QListWidgetItem *item);
     virtual void stopItemPreview(QListWidgetItem *item);
@@ -86,11 +86,11 @@ signals:
     void searchInfo(const QString &);
     void maxPages(int);
     /** @brief Emit meta info for current item in formatted html. */
-    void gotMetaInfo(const QString);
+    void gotMetaInfo(const QString &);
     /** @brief Emit some extra meta info (description, license). */
-    void gotMetaInfo(QMap <QString, QString> info);
+    void gotMetaInfo(const QMap <QString, QString> &info);
     /** @brief We have an url for current item's preview thumbnail. */
-    void gotThumb(const QString url);
+    void gotThumb(const QString &url);
     /** @brief The requested search query is finished. */
     void searchDone();
 };
